# lxd-io

Read [leveLXData](https://levelxdata.com/) datasets without boilerplate code.

Supported datasets are
* [exiD](https://www.exid-dataset.com/)
* [highD](https://highd-dataset.com/)
* [inD](https://www.ind-dataset.com/)
* [rounD](https://www.round-dataset.com/)
* [uniD](https://www.unid-dataset.com/)

## Install

Install with pip

```bash
python -m pip install lxd-io
```

## Use

Check [the tutorial notebook](https://github.com/lenvt/lxd-io/blob/main/tutorial.ipynb) or the tests to see usage examples.
